@@ -31,6 +31,7 @@
 
 #include "file-data.h"
 #include "file-utils.h"
+#include "glib-utils.h"
 #include "fr-command.h"
 #include "fr-command-iso.h"
 
@@ -83,8 +84,7 @@ list__process_line (char     *line,
 		return;
 
 	if (line[0] == 'D') {
-		if (comm_iso->cur_path != NULL)
-			g_free (comm_iso->cur_path);
+		g_free (comm_iso->cur_path);
 		comm_iso->cur_path = g_strdup (get_last_field (line, 4));
 		
 	} else if (line[0] == '-') { /* Is file */
@@ -93,7 +93,7 @@ list__process_line (char     *line,
 		fdata = file_data_new ();
 		
 		fields = split_line (line, 8);
-		fdata->size = atoll (fields[4]);
+		fdata->size = g_ascii_strtoull (fields[4], NULL, 10);
 		fdata->modified = mktime_from_string (fields[5], fields[6], fields[7]);
 		g_strfreev (fields);
 		
@@ -114,27 +114,38 @@ list__process_line (char     *line,
 			return;
 		}
 
-		fdata->original_path = fdata->full_path = g_strstrip (g_strconcat (comm_iso->cur_path, name_field, NULL));
+		if (comm_iso->cur_path[0] != '/') 
+			fdata->full_path = g_strstrip (g_strconcat ("/", comm_iso->cur_path, name_field, NULL));
+		else 
+			fdata->full_path = g_strstrip (g_strconcat (comm_iso->cur_path, name_field, NULL));
+		fdata->original_path = fdata->full_path + 1;
 		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 		fdata->path = remove_level_from_path (fdata->full_path);
-		fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
+
 		comm->file_list = g_list_prepend (comm->file_list, fdata);
 	}
 }
 
 
 static void
-fr_command_iso_list (FRCommand *comm)
+fr_command_iso_list (FRCommand  *comm,
+		     const char *password)
 {
+	FRCommandIso *comm_iso = FR_COMMAND_ISO (comm);
+	
+	g_free (comm_iso->cur_path);
+	comm_iso->cur_path = NULL;
+	
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
 				      list__process_line,
 				      comm);
 
-	fr_process_begin_command (comm->process, "isoinfo");
-	fr_process_add_arg (comm->process, "-J -R");
-	fr_process_add_arg (comm->process, "-l -i");
+	fr_process_begin_command (comm->process, "sh " PRIVEXECDIR "isoinfo.sh");
+	fr_process_add_arg (comm->process, "-i");
 	fr_process_add_arg (comm->process, comm->e_filename);
+	fr_process_add_arg (comm->process, "-l");
 	fr_process_end_command (comm->process);
+	
 	fr_process_start (comm->process);
 }
 
@@ -148,55 +159,47 @@ fr_command_iso_extract (FRCommand  *comm,
 			gboolean    junk_paths,
 			const char *password)
 {
+	char  *e_dest_dir;
 	GList *scan;
 
+	e_dest_dir = fr_command_escape (comm, dest_dir);
+
 	for (scan = file_list; scan; scan = scan->next) {
-		char       *scanpath = (char*)scan->data;
+		char       *path = scan->data;
 		const char *filename;
-                char       *fullpath, *temppath = NULL;
+                char       *file_dir, *e_temp_dest_dir = NULL, *temp_dest_dir = NULL;
 	
-		filename = file_name_from_path (scanpath);
-		temppath = remove_level_from_path (scanpath+1); /* Add one to ignore initial '/' */
-		if (temppath == NULL)
-			temppath = g_strdup ("/");
-		if (dest_dir != NULL) {
-			fullpath = g_build_filename (dest_dir, temppath, NULL);
-			g_free (temppath);
-		} else 
-			fullpath = temppath;
+		filename = file_name_from_path (path);
+		file_dir = remove_level_from_path (path);
+		if ((file_dir != NULL) && (strcmp (file_dir, "/") != 0)) 
+			e_temp_dest_dir = g_build_filename (e_dest_dir, file_dir, NULL);
+		 else 
+			e_temp_dest_dir = g_strdup (e_dest_dir);
+		g_free (file_dir);
+		
+		if (e_temp_dest_dir == NULL) 
+			continue;
 
-		ensure_dir_exists (fullpath, 0700);
+		temp_dest_dir = unescape_str (e_temp_dest_dir);
+		ensure_dir_exists (temp_dest_dir, 0700);
 
-		fr_process_begin_command (comm->process, "isoinfo");
-		fr_process_set_working_dir (comm->process, fullpath);
-		fr_process_add_arg (comm->process, "-J -R");
+		fr_process_begin_command (comm->process, "sh " PRIVEXECDIR "isoinfo.sh");
+		fr_process_set_working_dir (comm->process, temp_dest_dir);
 		fr_process_add_arg (comm->process, "-i");
 		fr_process_add_arg (comm->process, comm->e_filename);
 		fr_process_add_arg (comm->process, "-x");
-		fr_process_add_arg (comm->process, scanpath);
+		fr_process_add_arg (comm->process, path);
 		fr_process_add_arg (comm->process, ">");
 		fr_process_add_arg (comm->process, filename);
 		fr_process_end_command (comm->process);
-		fr_process_start (comm->process);
-		
-		g_free (fullpath);
+	
+		g_free (e_temp_dest_dir);
+		g_free (temp_dest_dir);
 	}
-}
 
+	g_free (e_dest_dir);
 
-static void
-fr_command_iso_handle_error (FRCommand   *comm, 
-			     FRProcError *error)
-{
-	if (error->type == 2) { /* ERROR: Unable to find Joliet SVD */
-
-		/* Remove the -J -R options and start again */
-		fr_process_set_arg_at (comm->process, 
-				       comm->process->error_command, 
-				       1, 
-				       "");
-		comm->process->restart = TRUE;
-	}
+	fr_process_start (comm->process);
 }
 
 
@@ -211,9 +214,8 @@ fr_command_iso_class_init (FRCommandIsoClass *class)
 
 	gobject_class->finalize = fr_command_iso_finalize;
 
-        afc->list           = fr_command_iso_list;
-	afc->extract        = fr_command_iso_extract;
-	afc->handle_error   = fr_command_iso_handle_error;
+        afc->list    = fr_command_iso_list;
+	afc->extract = fr_command_iso_extract;
 }
 
 
@@ -222,7 +224,10 @@ fr_command_iso_init (FRCommand *comm)
 {
 	FRCommandIso *comm_iso = FR_COMMAND_ISO (comm);
 
+	comm->file_type = FR_FILE_TYPE_ISO;
+
 	comm_iso->cur_path = NULL;
+	comm_iso->joliet = TRUE;
 	
 	comm->propCanModify                = FALSE;
 	comm->propAddCanUpdate             = FALSE;
@@ -239,9 +244,16 @@ fr_command_iso_init (FRCommand *comm)
 static void 
 fr_command_iso_finalize (GObject *object)
 {
+	FRCommandIso *comm_iso;
+	
         g_return_if_fail (object != NULL);
         g_return_if_fail (FR_IS_COMMAND_ISO (object));
 
+	comm_iso = FR_COMMAND_ISO (object);
+
+	g_free (comm_iso->cur_path);
+	comm_iso->cur_path = NULL;
+
 	/* Chain up */
         if (G_OBJECT_CLASS (parent_class)->finalize)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -282,7 +294,7 @@ fr_command_iso_new (FRProcess  *process,
 {
 	FRCommand *comm;
 
-	if (!is_program_in_path("isoinfo")) {
+	if (! is_program_in_path ("isoinfo")) {
 		return NULL;
 	}
 
