@@ -23,9 +23,14 @@
 #ifndef TYPEDEFS_H
 #define TYPEDEFS_H
 
+#define RC_DIR              ".gnome2/file-roller"
+#define RC_BOOKMARKS_FILE   ".gnome2/file-roller/bookmarks"
+#define RC_RECENT_FILE      ".gnome2/file-roller/recents"
+#define RC_OPTIONS_DIR      ".gnome2/file-roller/options"
 
-#define RC_BOOKMARKS_FILE ".file-roller/bookmarks"
-#define RC_RECENT_FILE    ".file-roller/recents"
+#define OLD_RC_BOOKMARKS_FILE   ".file-roller/bookmarks"
+#define OLD_RC_RECENT_FILE      ".file-roller/recents"
+#define OLD_RC_OPTIONS_DIR      ".file-roller/options"
 
 
 typedef enum {
@@ -49,7 +54,7 @@ typedef enum {
 	FR_COMPRESS_PROGRAM_BZIP,
 	FR_COMPRESS_PROGRAM_BZIP2,
 	FR_COMPRESS_PROGRAM_COMPRESS,
-	FR_COMPRESS_PROGRAM_LZOP,
+	FR_COMPRESS_PROGRAM_LZOP
 } FRCompressProgram;
 
 
@@ -57,7 +62,7 @@ typedef enum {
 	FR_COMPRESSION_VERY_FAST,
 	FR_COMPRESSION_FAST,
 	FR_COMPRESSION_NORMAL,
-	FR_COMPRESSION_MAXIMUM,
+	FR_COMPRESSION_MAXIMUM
 } FRCompression;
 
 
@@ -67,7 +72,8 @@ typedef enum {
 	FR_PROC_ERROR_COMMAND_NOT_FOUND,
 	FR_PROC_ERROR_EXITED_ABNORMALLY,
 	FR_PROC_ERROR_SPAWN,
-	FR_PROC_ERROR_STOPPED
+	FR_PROC_ERROR_STOPPED,
+	FR_PROC_ERROR_ASK_PASSWORD
 } FRProcErrorType;
 
 
@@ -78,5 +84,54 @@ typedef struct {
 } FRProcError;
 
 
+typedef enum {
+	FR_FILE_TYPE_ACE,
+	FR_FILE_TYPE_AR,
+	FR_FILE_TYPE_ARJ,
+	FR_FILE_TYPE_BZIP,
+	FR_FILE_TYPE_BZIP2,
+	FR_FILE_TYPE_COMPRESS,
+	FR_FILE_TYPE_CPIO,	
+	FR_FILE_TYPE_DEB,
+	FR_FILE_TYPE_ISO,
+	FR_FILE_TYPE_EAR,
+	FR_FILE_TYPE_GZIP,
+	FR_FILE_TYPE_JAR,
+	FR_FILE_TYPE_LHA,
+	FR_FILE_TYPE_LZOP,
+	FR_FILE_TYPE_RAR,
+	FR_FILE_TYPE_RPM,
+	FR_FILE_TYPE_TAR,
+	FR_FILE_TYPE_TAR_BZ,
+	FR_FILE_TYPE_TAR_BZ2,
+	FR_FILE_TYPE_TAR_GZ,
+	FR_FILE_TYPE_TAR_LZOP,
+	FR_FILE_TYPE_TAR_COMPRESS,
+	FR_FILE_TYPE_STUFFIT,
+	FR_FILE_TYPE_WAR,
+	FR_FILE_TYPE_ZIP,
+	FR_FILE_TYPE_ZOO,
+	FR_FILE_TYPE_7ZIP,
+	FR_FILE_TYPE_NULL
+} FRFileType;
+
+
+typedef struct {
+	FRFileType  id;
+	char       *ext;
+	char       *mime_type;
+	char       *name;
+} FRFileTypeDescription;
+
+
+typedef struct {
+	char       *command;
+	gboolean    can_open;
+	gboolean    can_save;
+	gboolean    support_many_files;
+	FRFileType  file_type;
+} FRCommandDescription;
+
+
 #endif /* TYPEDEFS_H */
 
